@@ -6,6 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 use Carp;
+use Log::Log4perl::Util;
 use Log::Log4perl::Level;
 use Log::Log4perl::DateFormat;
 use Log::Log4perl::NDC;
@@ -27,18 +28,20 @@ BEGIN {
     # just set a flag so we know later on that we can't have fine-grained
     # time stamps
     $TIME_HIRES_AVAILABLE = 0;
-    eval { require Time::HiRes; };
-    if($@) {
-        $PROGRAM_START_TIME = time();
-    } else {
+    if(Log::Log4perl::Util::module_available("Time::HiRes")) {
+        require Time::HiRes;
         $TIME_HIRES_AVAILABLE = 1;
         $PROGRAM_START_TIME = [Time::HiRes::gettimeofday()];
+    } else {
+        $PROGRAM_START_TIME = time();
     }
 
     # Check if we've got Sys::Hostname. If not, just punt.
     $HOSTNAME = "unknown.host";
-    eval { require Sys::Hostname; };
-    $HOSTNAME = Sys::Hostname::hostname() unless $@;
+    if(Log::Log4perl::Util::module_available("Sys::Hostname")) {
+        require Sys::Hostname;
+        $HOSTNAME = Sys::Hostname::hostname();
+    }
 }
 
 ##################################################
@@ -62,28 +65,26 @@ sub new {
     my $class = shift;
     $class = ref ($class) || $class;
 
-    my ($data) = @_;
-
-    my ($layout_string);
-
-    if (ref $data && !exists $data->{ConversionPattern}{value} or
-        !defined $data) {
-        #die "No ConversionPattern given for PatternLayout\n";
-        $layout_string = '%m%n';  #this is better per http://jakarta.apache.org/log4j/docs/api/org/apache/log4j/PatternLayout.html
-    } elsif (ref $data) {
-        $layout_string = $data->{ConversionPattern}{value};
-    } else {
-        $layout_string = $data;
+    my $options       = ref $_[0] eq "HASH" ? shift : {};
+    my $layout_string = @_ ? shift : '%m%n';
+    
+    if(exists $options->{ConversionPattern}->{value}) {
+        $layout_string = $options->{ConversionPattern}->{value};
     }
 
     my $self = {
-        format      => undef,
-        info_needed => {},
-        stack       => [],
-        CSPECS      => $CSPECS,
-        dontCollapseArrayRefs => $data->{dontCollapseArrayRefs}{value},
+        time_function         => \&current_time,
+        format                => undef,
+        info_needed           => {},
+        stack                 => [],
+        CSPECS                => $CSPECS,
+        dontCollapseArrayRefs => $options->{dontCollapseArrayRefs}{value},
     };
 
+    if(exists $options->{time_function}) {
+        $self->{time_function} = $options->{time_function};
+    }
+
     bless $self, $class;
 
     #add the global user-defined cspecs
@@ -95,8 +96,8 @@ sub new {
     }
 
     #add the user-defined cspecs local to this appender
-    foreach my $f (keys %{$data->{cspec}}){
-        $self->add_layout_cspec($f, $data->{cspec}{$f}{value});
+    foreach my $f (keys %{$options->{cspec}}){
+        $self->add_layout_cspec($f, $options->{cspec}{$f}{value});
     }
 
     $self->define($layout_string);
@@ -201,9 +202,18 @@ sub render {
         if($self->{info_needed}->{M} or
            $self->{info_needed}->{l} or
            0) {
-            # For the name of the subroutine the logger was triggered,
-            # we need to go one more level up
-            $subroutine = (caller($caller_level+1))[3];
+            # To obtain the name of the subroutine which triggered the 
+            # logger, we need to go one additional level up.
+            my $levels_up = 1; 
+            {
+                $subroutine = (caller($caller_level+$levels_up))[3];
+                    # If we're inside an eval, go up one level further.
+                if(defined $subroutine and
+                   $subroutine eq "(eval)") {
+                    $levels_up++;
+                    redo;
+                }
+            }
             $subroutine = "main::" unless $subroutine;
             $info{M} = $subroutine;
             $info{l} = "$subroutine $filename ($line)";
@@ -247,7 +257,7 @@ sub render {
     foreach my $cspec (keys %{$self->{USER_DEFINED_CSPECS}}){
         next unless $self->{info_needed}->{$cspec};
         $info{$cspec} = $self->{USER_DEFINED_CSPECS}->{$cspec}->($self, 
-                                $message, $category, $priority, $caller_level);
+                              $message, $category, $priority, $caller_level+1);
     }
 
         # Iterate over all info fields on the stack
@@ -256,11 +266,11 @@ sub render {
         if(exists $info{$op}) {
             my $result = $info{$op};
             if($curlies) {
-                $result = curly_action($op, $curlies, $info{$op});
+                $result = $self->curly_action($op, $curlies, $info{$op});
             } else {
                 # just for %d
                 if($op eq 'd') {
-                    $result = $info{$op}->format(current_time());
+                    $result = $info{$op}->format($self->{time_function}->());
                 }
             }
             push @results, $result;
@@ -278,7 +288,7 @@ sub render {
 ##################################################
 sub curly_action {
 ##################################################
-    my($ops, $curlies, $data) = @_;
+    my($self, $ops, $curlies, $data) = @_;
 
     if($ops eq "c") {
         $data = shrink_category($data, $curlies);
@@ -287,7 +297,7 @@ sub curly_action {
     } elsif($ops eq "X") {
         $data = Log::Log4perl::MDC->get($curlies);
     } elsif($ops eq "d") {
-        $data = $curlies->format(current_time());
+        $data = $curlies->format($self->{time_function}->());
     } elsif($ops eq "F") {
         my @parts = File::Spec->splitdir($data);
             # Limit it to max curlies entries
@@ -451,7 +461,7 @@ replaced by the logging engine when it's time to log the message:
     %C Fully qualified package (or class) name of the caller
     %d Current date in yyyy/MM/dd hh:mm:ss format
     %F File where the logging event occurred
-    %H Hostname
+    %H Hostname (if Sys::Hostname is available)
     %l Fully qualified name of the calling method followed by the
        callers source the file name and line number between 
        parentheses.
@@ -471,6 +481,9 @@ replaced by the logging engine when it's time to log the message:
 NDC and MDC are explained in L<Log::Log4perl/"Nested Diagnostic Context (NDC)">
 and L<Log::Log4perl/"Mapped Diagnostic Context (MDC)">.
 
+The granularity of time values is milliseconds if Time::HiRes is available.
+If not, only full seconds are used.
+
 =head2 Quantify placeholders
 
 All placeholders can be extended with formatting instructions,
@@ -610,6 +623,30 @@ before you call init().  Alternatively you can supply a restricted set of
 Perl opcodes that can be embedded in the config file as described in
 L<Log::Log4perl/"Restricting what Opcodes can be in a Perl Hook">.
   
+=head2 Advanced Options
+
+The constructor of the C<Log::Log4perl::Layout::PatternLayout> class
+takes an optional hash reference as a first argument to specify
+additional options in order to (ab)use it in creative ways:
+
+  my $layout = Log::Log4perl::Layout::PatternLayout->new(
+    { time_function       => \&my_time_func,
+    }, 
+    "%d (%F:%L)> %m");
+
+Here's a list of parameters:
+
+=over 4
+
+=item time_function
+
+Takes a reference to a function returning the time for the time/date
+fields, either in seconds
+since the epoch or as a reference to an array, carrying seconds and 
+microseconds, just like C<Time::HiRes::gettimeofday> does.
+
+=back
+
 =head1 SEE ALSO
 
 =head1 AUTHOR
